MapEntry

Enum MapEntry 

pub enum MapEntry {
    Skip,
    Keep {
        key: String,
        value: Value,
        recurse: bool,
    },
}
The result of mapping a single (key, value) pair.

Variants



Skip

Drop this entry from the result.



Keep

Keep the entry with the given key and value. recurse controls whether nested objects/arrays in the value are mapped (when deep is set); it defaults to true via MapEntry::keep.

Fields

key: String

The (possibly new) key.

value: Value

The (possibly new) value.

recurse: bool

Whether to recurse into value when deep is enabled.

Implementations

Source

impl MapEntry

pub fn keep(key: impl Into<String>, value: Value) -> Self

Keep the entry with the given key and value, recursing into it when deep.

pub fn keep_without_recursing(key: impl Into<String>, value: Value) -> Self

Keep the entry but do not recurse into its value, even when deep is set.